@@ -18,30 +18,31 @@
 #   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
 #set -x
-#verbose=0
-#if [ x$1 = x"" ]; then 
-#    export verbose=0
-#else
-#    export verbose=1
-#fi
 source $(dirname $0)/regexf_unittest.sh
-#source ./regexf_unittest.sh
 
 export PATH=.:$PATH
 
 # no_match returns false=1, match returns true=0
 configFile=/usr/local/bin/regexf.ini
-test_file=/usr/local/bin/regexf_test.ini
-
 assertEquals "regexf aa/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
 assertFalse "regexf aa/bb/cc"
-
 assertEquals "regexf aa/bb/cc vac/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
 assertGrep "regexf vac/bb/cc -v" " match"
 assertTrue "regexf vac/bb/cc"
-
 assertGrep "regexf -i -f $configFile" "regexf_version"
+# Even 1 no_match returns false
+assertTrue "regexf vac/vac1/1 vac/vac2/2" # matches return True
+assertFalse "regexf aa/bb/cc vac/vac1/1 vac/vac2/2" # 1 no_match return False
+assertFalse "regexf vac/vac1/1 aa/bb/cc vac/vac2/2" # 1 no_match return False
 
+#configFile=regexf.ini
+assertGrep "regexf -f $configFile -s test1 -i" "test1"
+assertGrep "regexf -f $configFile -s test1 a/d/g -v" "match"
+assertGrep "regexf -f $configFile -s test1 d/d/g -v" " no_match"
+assertGrep "regexf -f $configFile -s ego_test V1:A_B/bb/cc -v" " match"
+assertGrep "regexf -f $configFile -s ego_test V2:A_B/bb/cc -v" " no_match"
+
+test_file=/usr/local/bin/regexf_test.ini
 assertEquals "regexf -f $test_file aa/bb/cc" "$test_file:re.match<aa/bb/cc> no_match"
 assertFalse "regexf -f $test_file aa/bb/cc"
 assertEquals "regexf -f $test_file m/bb/cc" ""
@@ -52,3 +53,4 @@ assertGrep "regexf -f $test_file  b/bb/cc -v" " no_match"
 assertGrep "regexf -f $test_file V1:A_B/bb/cc -v" " no_match"
 assertGrep "regexf -f $test_file -s ego V1:A_B/bb/cc -v" " match"
 assertGrep "regexf -f $test_file -s ego V2:A_B/bb/cc -v" " no_match"
+
